@@ -199,6 +199,7 @@ def extract_captions(tex_file, sdir, image_list, primary=True):
     subfloat_head = u'\\subfloat'
     subfig_head = u'\\subfigure'
     includegraphics_head = u'\\includegraphics'
+    include_head = r'\\include(?!graphics)'  # matches only \include{}
     epsfig_head = u'\\epsfig'
     input_head = u'\\input'
     # possible caption lead-ins
@@ -257,7 +258,7 @@ def extract_captions(tex_file, sdir, image_list, primary=True):
         if line.find(doc_tail) > -1:
             break
 
-        """
+        r"""
         FIGURE -
         structure of a figure:
         \begin{figure}
@@ -337,7 +338,7 @@ def extract_captions(tex_file, sdir, image_list, primary=True):
                         break
                     already_tried.append(filename)
 
-        """
+        r"""
         INCLUDEGRAPHICS -
         structure of includegraphics:
         \includegraphics[someoptions]{FILENAME}
@@ -357,7 +358,7 @@ def extract_captions(tex_file, sdir, image_list, primary=True):
             else:
                 cur_image = ['', [cur_image, filename]]
 
-        """
+        r"""
         {\input{FILENAME}}
         \caption{CAPTION}
 
@@ -379,6 +380,26 @@ def extract_captions(tex_file, sdir, image_list, primary=True):
                             primary=False
                         ))
 
+        r"""
+        INCLUDE -
+        structure of include:
+        \include{FILENAME}
+        """
+        index = re.match(include_head, line)
+        if index:
+            new_tex_names = intelligently_find_filenames(
+                line, TeX=True,
+                commas_okay=commas_okay)
+            for new_tex_name in new_tex_names:
+                if new_tex_name != 'ERROR':
+                    new_tex_file = get_tex_location(new_tex_name, tex_file)
+                    if new_tex_file and primary:  # to kill recursion
+                        extracted_image_data.extend(extract_captions(
+                            new_tex_file, sdir,
+                            image_list,
+                            primary=False
+                        ))
+
         """PICTURE"""
 
         index = line.find(picture_head)
@@ -401,7 +422,7 @@ def extract_captions(tex_file, sdir, image_list, primary=True):
             # FIXME
             pass
 
-        """
+        r"""
         CAPTIONS -
         structure of a caption:
         \caption[someoptions]{CAPTION}
@@ -432,52 +453,27 @@ def extract_captions(tex_file, sdir, image_list, primary=True):
             elif caption != cur_caption:
                 caption = ['', [caption, cur_caption]]
 
-        """
-        SUBFLOATS -
-        structure of a subfloat (inside of a figure tag):
-        \subfloat[CAPTION]{options{FILENAME}}
-
-        also associated with the overall caption of the enclosing figure
-        """
-
-        index = line.find(subfloat_head)
-        if index > -1:
-            # if we are dealing with subfloats, we need a different
-            # sort of structure to keep track of captions and subcaptions
-            if not isinstance(cur_image, list):
-                cur_image = [cur_image, []]
-            if not isinstance(caption, list):
-                caption = [caption, []]
-
-            open_square, open_square_line, close_square, close_square_line = \
-                find_open_and_close_braces(line_index, index, '[', lines)
-            cap_begin = open_square + 1
-
-            sub_caption = assemble_caption(
-                open_square_line,
-                cap_begin, close_square_line, close_square, lines)
-            caption[SUB_CAPTION_OR_IMAGE].append(sub_caption)
-
-            open_curly, open_curly_line, close_curly, dummy = \
-                find_open_and_close_braces(close_square_line,
-                                           close_square, '{', lines)
-            sub_image = lines[open_curly_line][open_curly + 1:close_curly]
-
-            cur_image[SUB_CAPTION_OR_IMAGE].append(sub_image)
-
-        """
+        r"""
         SUBFIGURES -
         structure of a subfigure (inside a figure tag):
         \subfigure[CAPTION]{
         \includegraphics[options]{FILENAME}}
 
+        or
+
+        SUBFLOATS -
+        structure of a subfloat (inside of a figure tag):
+        \subfloat[CAPTION]{
+        \includegraphics[options]{FILENAME}}
+
+
         also associated with the overall caption of the enclosing figure
         """
 
-        index = line.find(subfig_head)
+        index = max([line.find(subfloat_head), line.find(subfig_head)])
         if index > -1:
-            # like with subfloats, we need a different structure for keepin
-            # track of this stuff
+            # we need a different structure for keeping track of several
+            # captions and images
             if type(cur_image) != list:
                 cur_image = [cur_image, []]
             if type(caption) != list:
@@ -512,7 +508,7 @@ def extract_captions(tex_file, sdir, image_list, primary=True):
 
             cur_image[SUB_CAPTION_OR_IMAGE].append(sub_image)
 
-        """
+        r"""
         LABELS -
         structure of a label:
         \label{somelabelnamewhichprobablyincludesacolon}
@@ -790,10 +786,10 @@ def intelligently_find_filenames(line, TeX=False, ext=False,
         valid_for_filename = '\\s*[A-Za-z0-9\\-\\=\\+/\\\\_\\.%#]+'
 
     if ext:
-        valid_for_filename += '\.e*ps[texfi2]*'
+        valid_for_filename += r'\.e*ps[texfi2]*'
 
     if TeX:
-        valid_for_filename += '[\.latex]*'
+        valid_for_filename += r'[\.latex]*'
 
     file_inclusion = re.findall('=' + valid_for_filename + '[ ,]', line)
 
